#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 glirc
version:              2.41
visibility:           public
id:                   glirc-2.41-EF0ska5avFV7IURPVxRkJy
key:                  glirc-2.41-EF0ska5avFV7IURPVxRkJy
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  a7ec290b6f861c7b5d7e165853c86d04
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Docs Client.Commands.Exec Client.Commands.Help
    Client.Commands.Interpolation Client.Commands.Operator
    Client.Commands.Queries Client.Commands.Recognizer
    Client.Commands.TabCompletion Client.Commands.Toggles
    Client.Commands.Types Client.Commands.Window
    Client.Commands.WordCompletion Client.Commands.ZNC
    Client.Configuration Client.Configuration.Colors
    Client.Configuration.Macros Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.Docs Client.EventLoop Client.EventLoop.Actions
    Client.EventLoop.Errors Client.EventLoop.Network Client.Hook
    Client.Hook.DroneBLRelay Client.Hook.Matterbridge
    Client.Hook.Snotice Client.Hook.Znc.Buffextras Client.Hooks
    Client.Image Client.Image.Focus Client.Image.Layout
    Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Help Client.State.Network
    Client.State.Target Client.State.Url Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.IgnoreList Client.View.KeyMap
    Client.View.MaskList Client.View.Mentions Client.View.Messages
    Client.View.Palette Client.View.RtsStats Client.View.UrlSelection
    Client.View.UserList Client.View.Who Client.View.WindowSwitch
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/glirc-2.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.41-EF0ska5avFV7IURPVxRkJy
include-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.9-66NbAyUwzQSHR2hFtOcR1x
    async-2.2.6-zgflWpTktJ30tej7mTLUV
    attoparsec-0.14.4-CUunZTxFwdu6Ra4s9CXGpL base-4.18.2.1
    base64-bytestring-1.2.1.0-HERFgBf9BNO9I6Z1qd2KAi
    bytestring-0.11.5.3 config-schema-1.3.0.0-HeIkhM8SAC77IKluFECL3Y
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    curve25519-0.2.8.1-CBaFREaPs56Fm9xeTk8sK0 directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-6iXANZcrS0NGofTL9Edf2u
    githash-0.1.7.0-K2rTsKcBN7DInT8Q6cdAU7
    hashable-1.4.7.0-Hz7Tlfd3lVGKIAup4AtUKB
    hookup-0.8-323yD4dgnqw1Xez63pismx
    irc-core-2.13-CgkeR4eyYjEjBlHGsEc5t
    kan-extensions-5.2.8-AsQfvJevO4KLFFufIivs9k
    lens-5.3.4-GEByP8NohgN7QTNjru7SEZ
    network-3.1.4.0-GKsJfMxK7ta75dRCMdxvzp
    psqueues-0.2.8.3-FeL8HsVL2gOAygqodPMZ9R
    random-1.2.1.3-9HnDVtmtwMCAuyzxGkvhji
    regex-tdfa-1.3.2.5-Ckv8OQ26XNDHjQnoyw4S47
    semigroupoids-6.0.2-CunPpNFb9oe2uRkoj2NpGV
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 typed-process-0.2.13.0-HYVKbfJEaKk8bzlMPETUOR
    unix-2.8.4.0 unordered-containers-0.2.20.1-1CoVa9Q6EKSEUs7sPAJfW1
    vector-0.13.2.0-7BVLr4DYOHu1u41KuR5SBY
    vty-6.2-1wlksJOGnmt1Qknixg90Gp

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

